@@ -15,12 +15,17 @@
 
 """Callback that can be used within Hexaly."""
 
+from __future__ import annotations
+
 from abc import abstractmethod
+from typing import TYPE_CHECKING
 from typing import ClassVar
 
-from hexaly.optimizer import HexalyOptimizer
 from hexaly.optimizer import HxCallbackType
 
+if TYPE_CHECKING:
+    from hexaly.optimizer import HexalyOptimizer
+
 
 class HexalyCallback:
     """A Hexaly callback."""
